NAME
VLGal::Style - contains VLGal code style information
SYNOPSIS
TODO
ABSTRACT
Vincenzo's little gallery style
DESCRIPTION
VLGal::Style class to style Vincenzo's little gallery.
CONSTRUCTOR
- new( [ OPT_HASH_REF ] )
-
Creates a new
VLGal::Styleobject.OPT_HASH_REFis a hash reference used to pass initialization options. On error an exceptionError::Simpleis thrown.Options for
OPT_HASH_REFmay include:css_definition_file-
Passed to set_css_definition_file(). Defaults to the VLGal/lib/default.css file in
@INC. image_icon_folder-
Passed to set_image_icon_folder(). Defaults to the VLGal/lib/icon-folder.png file in
@INC. image_icon_next_peer-
Passed to set_image_icon_next_peer(). Defaults to the VLGal/lib/icon-next-peer.png file in
@INC. image_icon_next_seq-
Passed to set_image_icon_next_seq(). Defaults to the VLGal/lib/icon-next-seq.png file in
@INC. image_icon_previous_peer-
Passed to set_image_icon_previous_peer(). Defaults to the VLGal/lib/icon-previous-peer.png file in
@INC. image_icon_previous_seq-
Passed to set_image_icon_previous_seq(). Defaults to the VLGal/lib/icon-previous-seq.png file in
@INC. max_columns_dir-
Passed to set_max_columns_dir(). Defaults to 8.
max_columns_image-
Passed to set_max_columns_image(). Defaults to 5.
size-
Passed to set_size(). Must be an
ARRAYreference. Defaults to:[ VLGal::Size->new( { max_height => 90, max_width => 90, } ), VLGal::Size->new( { max_height => 600, max_width => 600, } ), VLGal::Size->new( { max_height => 800, max_width => 800, } ), VLGal::Size->new( { max_height => 1000, max_width => 1000, } ), VLGal::Size->new( { max_height => 0, max_width => 0, } ), ], table_order_dir-
Passed to set_table_order_dir(). Defaults to 'n'.
table_order_image-
Passed to set_table_order_image(). Defaults to 'z'.
verbose-
Passed to set_verbose().
METHODS
- exists_size(ARRAY)
-
Returns the count of items in
ARRAYthat are in the list of size description objects for the file. - get_css_definition_file()
-
Returns the css definition file to use.
- get_image_icon_folder()
-
Returns the icon image to use to view a child page in the gallery.
- get_image_icon_next_peer()
-
Returns the icon image to use to view the next peer in the gallery.
- get_image_icon_next_seq()
-
Returns the icon image to use to view the next item in sequence in the gallery.
- get_image_icon_previous_peer()
-
Returns the icon image to use to view the previous peer in the gallery.
- get_image_icon_previous_seq()
-
Returns the icon image to use to view the previous item in sequence in the gallery.
- get_max_columns_dir()
-
Returns the maximal amount of columns in the directory table.
- get_max_columns_image()
-
Returns the maximal amount of columns in the image table.
- get_size( [ INDEX_ARRAY ] )
-
Returns an
ARRAYcontaining the list of size description objects for the file.INDEX_ARRAYis an optional list of indexes which when specified causes only the indexed elements in the ordered list to be returned. If not specified, all elements are returned. - get_table_order_dir()
-
Returns the table ordering for directories.
- get_table_order_image()
-
Returns the table ordering for images.
- instance( [ CONSTR_OPT ] )
-
Always returns the same
VLGal::Style-singleton- object instance. The first time it is called, parametersCONSTR_OPT-if specified- are passed to the constructor. - is_verbose()
-
Returns whether to print messages to
STDERRduringhtmlcode generation and image scaling or not. - pop_size()
-
Pop and return an element off the list of size description objects for the file. On error an exception
Error::Simpleis thrown. - push_size(ARRAY)
-
Push additional values on the list of size description objects for the file.
ARRAYis the list value. On error an exceptionError::Simpleis thrown. - set_css_definition_file(VALUE)
-
Set the css definition file to use.
VALUEis the value. Default value at initialization is the VLGal/lib/default.css file in@INC. On error an exceptionError::Simpleis thrown. - set_idx_size( INDEX, VALUE )
-
Set value in the list of size description objects for the file.
INDEXis the integer index which is greater than or equal to0.VALUEis the value. - set_image_icon_folder(VALUE)
-
Set the icon image to use to view a child page in the gallery.
VALUEis the value. Default value at initialization is the VLGal/lib/icon-folder.png file in@INC. On error an exceptionError::Simpleis thrown. - set_image_icon_next_peer(VALUE)
-
Set the icon image to use to view the next peer in the gallery.
VALUEis the value. Default value at initialization is the VLGal/lib/icon-next-peer.png file in@INC. On error an exceptionError::Simpleis thrown. - set_image_icon_next_seq(VALUE)
-
Set the icon image to use to view the next item in sequence in the gallery.
VALUEis the value. Default value at initialization is the VLGal/lib/icon-next-seq.png file in@INC. On error an exceptionError::Simpleis thrown. - set_image_icon_previous_peer(VALUE)
-
Set the icon image to use to view the previous peer in the gallery.
VALUEis the value. Default value at initialization is the VLGal/lib/icon-previous-peer.png file in@INC. On error an exceptionError::Simpleis thrown. - set_image_icon_previous_seq(VALUE)
-
Set the icon image to use to view the previous item in sequence in the gallery.
VALUEis the value. Default value at initialization is the VLGal/lib/icon-previous-seq.png file in@INC. On error an exceptionError::Simpleis thrown. - set_max_columns_dir(VALUE)
-
Set the maximal amount of columns in the directory table.
VALUEis the value. Default value at initialization is8. On error an exceptionError::Simpleis thrown. - set_max_columns_image(VALUE)
-
Set the maximal amount of columns in the image table.
VALUEis the value. Default value at initialization is5. On error an exceptionError::Simpleis thrown. - set_num_size( NUMBER, VALUE )
-
Set value in the list of size description objects for the file.
NUMBERis the integer index which is greater than0.VALUEis the value. - set_size(ARRAY)
-
Set the list of size description objects for the file absolutely.
ARRAYis the list value. Default value at initialization is:[ VLGal::Size->new( { max_height => 90, max_width => 90, } ), VLGal::Size->new( { max_height => 600, max_width => 600, } ), VLGal::Size->new( { max_height => 800, max_width => 800, } ), VLGal::Size->new( { max_height => 1000, max_width => 1000, } ), VLGal::Size->new( { max_height => 0, max_width => 0, } ), ],On error an exception
Error::Simpleis thrown. - set_table_order_dir(VALUE)
-
Set the table ordering for directories.
VALUEis the value. Default value at initialization isn. On error an exceptionError::Simpleis thrown. - set_table_order_image(VALUE)
-
Set the table ordering for images.
VALUEis the value. Default value at initialization isz. On error an exceptionError::Simpleis thrown. - set_verbose(VALUE)
-
State that to print messages to
STDERRduringhtmlcode generation and image scaling.VALUEis the value. On error an exceptionError::Simpleis thrown. - shift_size()
-
Shift and return an element off the list of size description objects for the file. On error an exception
Error::Simpleis thrown. - unshift_size(ARRAY)
-
Unshift additional values on the list of size description objects for the file.
ARRAYis the list value. On error an exceptionError::Simpleis thrown.
SEE ALSO
VLGal::Directory, VLGal::File, VLGal::File::Factory, VLGal::File::MMagic, VLGal::Size
BUGS
None known (yet.)
HISTORY
First development: September 2003 Last update: October 2003
AUTHOR
Vincenzo Zocca
COPYRIGHT
Copyright 2003 by Vincenzo Zocca
LICENSE
This file is part of the VLGal module hierarchy for Perl by Vincenzo Zocca.
The VLGal module hierarchy is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
The VLGal module hierarchy is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with the VLGal module hierarchy; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA